# generated by datamodel-codegen:
#   filename:  <stdin>

from __future__ import annotations

from typing import List

from pydantic import BaseModel, Extra


class Ignore(BaseModel):
    class Config:
        extra = Extra.forbid

    paths: List[str]


class Build(BaseModel):
    class Config:
        extra = Extra.forbid

    ignore: Ignore
    base_branch: str


class Release(BaseModel):
    class Config:
        extra = Extra.forbid

    timeout_in_minutes: int


class Config(BaseModel):
    class Config:
        extra = Extra.forbid

    build: Build
    release: Release
